==> slang_2024.13~rc2-1lunarg22.04.orig.tar.gz: slang-2024.13~rc2-1lunarg22.04/external/slang-rhi/src/wgpu/wgpu-sampler.cpp <==
#include "wgpu-sampler.h"
#include "wgpu-device.h"
#include "wgpu-util.h"

namespace rhi::wgpu {

SamplerImpl::SamplerImpl(DeviceImpl* device, const SamplerDesc& desc)
    : Sampler(desc)
    , m_device(device)
{
}

SamplerImpl::~SamplerImpl()
{
    if (m_sampler)
    {
        m_device->m_ctx.api.wgpuSamplerRelease(m_sampler);
    }
}

Result SamplerImpl::getNativeHandle(NativeHandle* outHandle)
{
    outHandle->type = NativeHandleType::WGPUSampler;
    outHandle->value = (uint64_t)m_sampler;
    return SLANG_OK;
}

Result DeviceImpl::createSampler(SamplerDesc const& desc, ISampler** outSampler)
{
    RefPtr<SamplerImpl> sampler = new SamplerImpl(this, desc);
    WGPUSamplerDescriptor samplerDesc = {};
    samplerDesc.addressModeU = translateAddressMode(desc.addressU);
    samplerDesc.addressModeV = translateAddressMode(desc.addressV);
    samplerDesc.addressModeW = translateAddressMode(desc.addressW);
    samplerDesc.magFilter = translateFilterMode(desc.magFilter);
    samplerDesc.minFilter = translateFilterMode(desc.minFilter);
    samplerDesc.mipmapFilter = translateMipmapFilterMode(desc.mipFilter);
    samplerDesc.lodMinClamp = desc.minLOD;
    samplerDesc.lodMaxClamp = desc.maxLOD;
    if (desc.reductionOp == TextureReductionOp::Comparison)
    {
        samplerDesc.compare = translateCompareFunction(desc.comparisonFunc);
    }
    samplerDesc.maxAnisotropy = desc.maxAnisotropy;
    samplerDesc.label = desc.label;
    sampler->m_sampler = m_ctx.api.wgpuDeviceCreateSampler(m_ctx.device, &samplerDesc);
    if (!sampler->m_sampler)
    {
        return SLANG_FAIL;
    }
    returnComPtr(outSampler, sampler);
    return SLANG_OK;
}

} // namespace rhi::wgpu

==> slang_2025.6.1~rc1-1lunarg22.04.orig.tar.gz: slang-2025.6.1~rc1-1lunarg22.04/external/slang-rhi/src/wgpu/wgpu-sampler.cpp <==
#include "wgpu-sampler.h"
#include "wgpu-device.h"
#include "wgpu-util.h"

namespace rhi::wgpu {

SamplerImpl::SamplerImpl(DeviceImpl* device, const SamplerDesc& desc)
    : Sampler(desc)
    , m_device(device)
{
}

SamplerImpl::~SamplerImpl()
{
    if (m_sampler)
    {
        m_device->m_ctx.api.wgpuSamplerRelease(m_sampler);
    }
}

Result SamplerImpl::getNativeHandle(NativeHandle* outHandle)
{
    outHandle->type = NativeHandleType::WGPUSampler;
    outHandle->value = (uint64_t)m_sampler;
    return SLANG_OK;
}

Result DeviceImpl::createSampler(const SamplerDesc& desc, ISampler** outSampler)
{
    RefPtr<SamplerImpl> sampler = new SamplerImpl(this, desc);
    WGPUSamplerDescriptor samplerDesc = {};
    samplerDesc.addressModeU = translateAddressMode(desc.addressU);
    samplerDesc.addressModeV = translateAddressMode(desc.addressV);
    samplerDesc.addressModeW = translateAddressMode(desc.addressW);
    samplerDesc.magFilter = translateFilterMode(desc.magFilter);
    samplerDesc.minFilter = translateFilterMode(desc.minFilter);
    samplerDesc.mipmapFilter = translateMipmapFilterMode(desc.mipFilter);
    samplerDesc.lodMinClamp = desc.minLOD;
    samplerDesc.lodMaxClamp = desc.maxLOD;
    if (desc.reductionOp == TextureReductionOp::Comparison)
    {
        samplerDesc.compare = translateCompareFunction(desc.comparisonFunc);
    }
    samplerDesc.maxAnisotropy = desc.maxAnisotropy;
    samplerDesc.label = desc.label;
    sampler->m_sampler = m_ctx.api.wgpuDeviceCreateSampler(m_ctx.device, &samplerDesc);
    if (!sampler->m_sampler)
    {
        return SLANG_FAIL;
    }
    returnComPtr(outSampler, sampler);
    return SLANG_OK;
}

} // namespace rhi::wgpu
